@@ -70,7 +70,7 @@ class CeleryHaystackSignalHandler(Task):
             instance = model_class.objects.get(pk=int(pk))
         except model_class.DoesNotExist:
             logger.error("Couldn't load model instance "
-                         "with pk #%s. Somehow it went missing? %s" % pk)
+                         "with pk #%s. Somehow it went missing?" % pk)
             return None
         except model_class.MultipleObjectsReturned:
             logger.error("More than one object with pk #%s. Oops?" % pk)
